@@ -20,6 +20,7 @@ from osc_lib.command import command
 from osc_lib import utils
 
 from tackerclient.common import exceptions
+from tackerclient.common import utils as tacker_common_utils
 from tackerclient.i18n import _
 from tackerclient.osc import sdk_utils
 from tackerclient.osc import utils as tacker_osc_utils
@@ -169,6 +170,7 @@ class CreateVNFFG(command.ShowOne):
         return body
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         vnffg = client.create_vnffg(self.args2body(parsed_args))
         display_columns, columns = _get_columns(vnffg[_VNFFG])
@@ -190,18 +192,33 @@ class DeleteVNFFG(command.Command):
             nargs="+",
             help=_("VNFFG(s) to delete (name or ID)")
         )
+        parser.add_argument(
+            '--force',
+            default=False,
+            action='store_true',
+            help=_('Force delete VNFFG'))
         return parser
 
+    def args2body(self, parsed_args):
+        body = dict()
+        if parsed_args.force:
+            body[_VNFFG] = dict()
+            body[_VNFFG]['attributes'] = dict()
+            body[_VNFFG]['attributes']['force'] = True
+        return body
+
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         failure = False
         deleted_ids = []
         failed_items = {}
+        body = self.args2body(parsed_args)
         for resource_id in parsed_args.vnffg:
             try:
                 obj = tackerV10.find_resourceid_by_name_or_id(
                     client, _VNFFG, resource_id)
-                client.delete_vnffg(obj)
+                client.delete_vnffg(obj, body)
                 deleted_ids.append(resource_id)
             except Exception as e:
                 failure = True
@@ -251,6 +268,9 @@ class UpdateVNFFG(command.ShowOne):
         parser.add_argument(
             '--description',
             help=_('Set a description for the VNFFG'))
+        parser.add_argument(
+            '--param-file',
+            help=_('YAML file with specific VNFFG parameters'))
         return parser
 
     def args2body(self, parsed_args):
@@ -294,11 +314,12 @@ class UpdateVNFFG(command.ShowOne):
                 raise exceptions.InvalidInput(
                     reason='The parameter file is empty')
             body[_VNFFG]['attributes'] = {'param_values': param_yaml}
-        tackerV10.update_dict(parsed_args, body[self.resource],
+        tackerV10.update_dict(parsed_args, body[_VNFFG],
                               ['vnf_mapping', 'symmetrical', 'description'])
         return body
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         obj_id = tackerV10.find_resourceid_by_name_or_id(
             client, _VNFFG, parsed_args.vnffg)
@@ -324,6 +345,7 @@ class ListVNFFG(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         data = client.list_vnffgs()
         headers, columns = tacker_osc_utils.get_column_definitions(
@@ -347,6 +369,7 @@ class ShowVNFFG(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         obj_id = tackerV10.find_resourceid_by_name_or_id(
             client, _VNFFG, parsed_args.vnffg)
@@ -370,6 +393,7 @@ class ListNFP(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         _params = {}
         if parsed_args.vnffg_id:
@@ -406,6 +430,7 @@ class ShowNFP(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         obj_id = tackerV10.find_resourceid_by_name_or_id(
             client, _NFP, parsed_args.nfp)
@@ -431,6 +456,7 @@ class ListFC(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         _params = {}
         if parsed_args.nfp_id:
@@ -470,6 +496,7 @@ class ShowFC(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         obj_id = tackerV10.find_resourceid_by_name_or_id(
             client, _FC, parsed_args.classifier)
@@ -496,6 +523,7 @@ class ListSFC(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         _params = {}
         if parsed_args.nfp_id:
@@ -533,6 +561,7 @@ class ShowSFC(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
+        tacker_common_utils.deprecate_legacy_warning()
         client = self.app.client_manager.tackerclient
         obj_id = tackerV10.find_resourceid_by_name_or_id(
             client, _SFC, parsed_args.sfc)
