@@ -653,8 +653,8 @@ class CLITestV10Base(testtools.TestCase):
 class ClientV1TestJson(CLITestV10Base):
     def test_do_request_unicode(self):
         self.client.format = self.format
-        unicode_text = u'\u7f51\u7edc'
-        action = u'/test'
+        unicode_text = '\u7f51\u7edc'
+        action = '/test'
         params = {'test': unicode_text}
         body = params
         expect_body = self.client.serialize(body)
@@ -663,7 +663,7 @@ class ClientV1TestJson(CLITestV10Base):
             mock_req.return_value = (MyResp(200), expect_body)
             res_body = self.client.do_request('PUT', action, body=body,
                                               params=params)
-            expected_uri = u'localurl/v1.0/test.json?test=%E7%BD%91%E7%BB%9C'
+            expected_uri = 'localurl/v1.0/test.json?test=%E7%BD%91%E7%BB%9C'
             mock_req.assert_called_with(
                 expected_uri, 'PUT', body=expect_body,
                 headers={'X-Auth-Token': unicode_text,
@@ -798,3 +798,27 @@ class CLITestV10ExceptionHandler(CLITestV10Base):
             exceptions.TackerClientException, 500,
             expected_msg=expected_msg,
             error_content=error_content)
+
+    def test_exception_handler_v10_tacker_etsi_error(self):
+        """Test ETSI error response"""
+
+        known_error_map = [
+            ({
+                "status": "status 1",
+                "detail": "sample 1"
+            }, 400),
+            ({
+                "status": "status 2",
+                "detail": "sample 2"
+            }, 404),
+            ({
+                "status": "status 3",
+                "detail": "sample 3"
+            }, 409)
+        ]
+
+        for error_content, status_code in known_error_map:
+            self._test_exception_handler_v10(
+                exceptions.TackerClientException, status_code,
+                expected_msg=error_content['detail'],
+                error_content=error_content)
